==> ugene_1.3.3+repack.orig.tar.gz: ugene-1.3.3/src/plugins/annotator/src/AnnotatorTests.cpp <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#include "AnnotatorTests.h"
#include <QStringList>

#include <datatype/DNASequence.h>

#include <core_api/DocumentModel.h>
#include <core_api/DocumentFormats.h>
#include <core_api/GObject.h>

#include <gobjects/GObjectTypes.h>
#include <gobjects/DNASequenceObject.h>
#include <test_framework/xmltest/DocumentModelTests.h>
#include <test_framework/GTestFrameworkComponents.h>

/* TRANSLATOR GB2::GTest */

namespace GB2 {

#define GROUPS_ATTR "groups"
#define REGION_SIZE_ATTR "region_size"
#define FIT_TO_REGION_ATTR "is_fit_to_region"
#define DOC_ATTR "doc"
#define SEQ_ATTR "seq"
#define EXPECTED_RESULTS_ATTR  "expected_results"

void GTest_AnnotatorSearch::init(XMLTestFormat *tf, const QDomElement& el) {
	Q_UNUSED(tf);

	docName = el.attribute(DOC_ATTR);
	if (docName.isEmpty()) {
		stateInfo.error = GTest::tr("value not set %1").arg(DOC_ATTR);
		return;
	} 

	seqName = el.attribute(SEQ_ATTR);
	if (seqName.isEmpty()) {
		stateInfo.error = GTest::tr("value not set %1").arg(SEQ_ATTR);
		return;
	}

	QString groups = el.attribute(GROUPS_ATTR);
	if (groups.isEmpty()) {
		stateInfo.error = GTest::tr("value not set %1").arg(GROUPS_ATTR);
		return;
	} 
	groupsToSearch = (groups.split(QRegExp("\\,"))).toSet(); //may be QRegExp("\\,")

	QString expected = el.attribute(EXPECTED_RESULTS_ATTR);
	if (!expected.isEmpty()) {
		QStringList expectedList = expected.split(QRegExp("\\,")); //may be QRegExp("\\,")
		foreach(QString region, expectedList) {
			QStringList bounds = region.split(QRegExp("\\.."));
			if (bounds.size() != 2) {
				stateInfo.error = GTest::tr("wrong value for %1").arg(EXPECTED_RESULTS_ATTR);
				return;
			}
			bool startOk, finishOk;
			int start = bounds.first().toInt(&startOk), finish = bounds.last().toInt(&finishOk);
			if (startOk && finishOk != true) {
				stateInfo.error = GTest::tr("wrong value for %1").arg(EXPECTED_RESULTS_ATTR);
				return;
			}
			start--;
			expectedResults.append(LRegion(start, finish - start));
		}
	} 
	
	QString strRegionSize = el.attribute(REGION_SIZE_ATTR);
	if (strRegionSize.isEmpty()) {
		stateInfo.error = GTest::tr("value not set %1").arg(REGION_SIZE_ATTR);
		return;
	}
	bool isOk = false;
	regionSize = strRegionSize.toInt(&isOk);
	if (!isOk) {
		stateInfo.error = GTest::tr("Unable to convert. Value wrong %1").arg(REGION_SIZE_ATTR);
		return;
	}

	QString strFitToRegion = el.attribute(FIT_TO_REGION_ATTR);
	if (strRegionSize.isEmpty()) {
		stateInfo.error = GTest::tr("value not set %1").arg(FIT_TO_REGION_ATTR);
		return;
	} 
	if (strFitToRegion == "true") {
		st = CollocationsAlgorithm::NormalSearch;
	} else if (strFitToRegion == "false"){
		st = CollocationsAlgorithm::PartialSearch;
	} else {
		stateInfo.error = GTest::tr("Unable to convert. Value wrong %1").arg(FIT_TO_REGION_ATTR);
		return;
	}	
}

void GTest_AnnotatorSearch::prepare() {
/**/
	Document* doc = getContext<Document>(this, docName);
	if (doc == NULL) {
		stateInfo.error = GTest::tr("context not found %1").arg(docName);
		return;
	}

	QList<GObject*> list = doc->findGObjectByType(GObjectTypes::DNA_SEQUENCE);
	if (list.size() == 0) {
		stateInfo.error = GTest::tr("container of object with type \"%1\" is empty").arg(GObjectTypes::DNA_SEQUENCE);
		return;
	}
	GObject *obj = list.first();
	if(obj==NULL){
		stateInfo.error = GTest::tr("object with type \"%1\" not found").arg(GObjectTypes::DNA_SEQUENCE);
		return;
	}
	assert(obj!=NULL);
	DNASequenceObject * mySequence = qobject_cast<DNASequenceObject*>(obj);
	if(mySequence==NULL){
		stateInfo.error = GTest::tr("error can't cast to sequence from GObject");
		return;
	}
	AnnotationTableObject* ao =  getContext<AnnotationTableObject>(this, seqName);
	if(ao==NULL){
		stateInfo.error = GTest::tr("context not found %1").arg(seqName);
		return;
	}
	QList<AnnotationTableObject*> aoList;
	aoList.append(ao);
    CollocationsAlgorithmSettings cfg;
    cfg.distance = regionSize;
    cfg.searchRegion = mySequence->getSequenceRange();
    cfg.st = st;
	searchTask = new CollocationSearchTask(aoList, groupsToSearch, cfg);
	addSubTask(searchTask);
}

Task::ReportResult GTest_AnnotatorSearch::report() {
	QList<LRegion> actualResults = searchTask->popResults();
	int actualSize = actualResults.size(), expectedSize = expectedResults.size();
	if (actualSize != expectedSize) {
		stateInfo.error = GTest::tr("Expected and Actual lists of regions are different: %1 %2").arg(expectedSize).arg(actualSize);
		return ReportResult_Finished;
	}
	qSort(actualResults); qSort(expectedResults);
	if (actualResults != expectedResults) {
		stateInfo.error = GTest::tr("One of the expected regions not found in results").arg(expectedSize).arg(actualSize);
		return ReportResult_Finished;
	}
	return ReportResult_Finished;
}

void GTest_AnnotatorSearch::cleanup() {
    //delete searchTask;
    searchTask = NULL;
}

} //namespace

==> ugene_1.5.2+repack.orig.tar.gz: ugene-1.5.2/src/plugins/annotator/src/AnnotatorTests.cpp <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#include "AnnotatorTests.h"
#include <QStringList>

#include <datatype/DNASequence.h>

#include <core_api/DocumentModel.h>
#include <core_api/DocumentFormats.h>
#include <core_api/GObject.h>

#include <gobjects/GObjectTypes.h>
#include <gobjects/DNASequenceObject.h>
#include <test_framework/xmltest/DocumentModelTests.h>
#include <test_framework/GTestFrameworkComponents.h>

/* TRANSLATOR GB2::GTest */

namespace GB2 {

#define GROUPS_ATTR "groups"
#define REGION_SIZE_ATTR "region_size"
#define FIT_TO_REGION_ATTR "is_fit_to_region"
#define DOC_ATTR "doc"
#define SEQ_ATTR "seq"
#define EXPECTED_RESULTS_ATTR  "expected_results"

void GTest_AnnotatorSearch::init(XMLTestFormat *tf, const QDomElement& el) {
	Q_UNUSED(tf);

	docName = el.attribute(DOC_ATTR);
	if (docName.isEmpty()) {
		failMissingValue(DOC_ATTR);
		return;
	} 

	seqName = el.attribute(SEQ_ATTR);
	if (seqName.isEmpty()) {
		failMissingValue(SEQ_ATTR);
		return;
	}

	QString groups = el.attribute(GROUPS_ATTR);
	if (groups.isEmpty()) {
		failMissingValue(GROUPS_ATTR);
		return;
	} 
	groupsToSearch = (groups.split(QRegExp("\\,"))).toSet(); //may be QRegExp("\\,")

	QString expected = el.attribute(EXPECTED_RESULTS_ATTR);
	if (!expected.isEmpty()) {
		QStringList expectedList = expected.split(QRegExp("\\,")); //may be QRegExp("\\,")
		foreach(QString region, expectedList) {
			QStringList bounds = region.split(QRegExp("\\.."));
			if (bounds.size() != 2) {
				stateInfo.setError(  QString("wrong value for %1").arg(EXPECTED_RESULTS_ATTR) );
				return;
			}
			bool startOk, finishOk;
			int start = bounds.first().toInt(&startOk), finish = bounds.last().toInt(&finishOk);
			if (startOk && finishOk != true) {
				stateInfo.setError(  QString("wrong value for %1").arg(EXPECTED_RESULTS_ATTR) );
				return;
			}
			start--;
			expectedResults.append(LRegion(start, finish - start));
		}
	} 
	
	QString strRegionSize = el.attribute(REGION_SIZE_ATTR);
	if (strRegionSize.isEmpty()) {
		failMissingValue(REGION_SIZE_ATTR);
		return;
	}
	bool isOk = false;
	regionSize = strRegionSize.toInt(&isOk);
	if (!isOk) {
		stateInfo.setError(  QString("Unable to convert. Value wrong %1").arg(REGION_SIZE_ATTR) );
		return;
	}

	QString strFitToRegion = el.attribute(FIT_TO_REGION_ATTR);
	if (strRegionSize.isEmpty()) {
		failMissingValue(FIT_TO_REGION_ATTR);
		return;
	} 
	if (strFitToRegion == "true") {
		st = CollocationsAlgorithm::NormalSearch;
	} else if (strFitToRegion == "false"){
		st = CollocationsAlgorithm::PartialSearch;
	} else {
		stateInfo.setError(  QString("Unable to convert. Value wrong %1").arg(FIT_TO_REGION_ATTR) );
		return;
	}	
}

void GTest_AnnotatorSearch::prepare() {
/**/
	Document* doc = getContext<Document>(this, docName);
	if (doc == NULL) {
		stateInfo.setError(  QString("context not found %1").arg(docName) );
		return;
	}

	QList<GObject*> list = doc->findGObjectByType(GObjectTypes::DNA_SEQUENCE);
	if (list.size() == 0) {
		stateInfo.setError(  QString("container of object with type \"%1\" is empty").arg(GObjectTypes::DNA_SEQUENCE) );
		return;
	}
	GObject *obj = list.first();
	if(obj==NULL){
		stateInfo.setError(  QString("object with type \"%1\" not found").arg(GObjectTypes::DNA_SEQUENCE) );
		return;
	}
	assert(obj!=NULL);
	DNASequenceObject * mySequence = qobject_cast<DNASequenceObject*>(obj);
	if(mySequence==NULL){
		stateInfo.setError(  QString("error can't cast to sequence from GObject") );
		return;
	}
	AnnotationTableObject* ao =  getContext<AnnotationTableObject>(this, seqName);
	if(ao==NULL){
		stateInfo.setError(  QString("context not found %1").arg(seqName) );
		return;
	}
	QList<AnnotationTableObject*> aoList;
	aoList.append(ao);
    CollocationsAlgorithmSettings cfg;
    cfg.distance = regionSize;
    cfg.searchRegion = mySequence->getSequenceRange();
    cfg.st = st;
	searchTask = new CollocationSearchTask(aoList, groupsToSearch, cfg);
	addSubTask(searchTask);
}

Task::ReportResult GTest_AnnotatorSearch::report() {
	QList<LRegion> actualResults = searchTask->popResults();
	int actualSize = actualResults.size(), expectedSize = expectedResults.size();
	if (actualSize != expectedSize) {
		stateInfo.setError(  QString("Expected and Actual lists of regions are different: %1 %2").arg(expectedSize).arg(actualSize) );
		return ReportResult_Finished;
	}
	qSort(actualResults); qSort(expectedResults);
	if (actualResults != expectedResults) {
		stateInfo.setError(  QString("One of the expected regions not found in results").arg(expectedSize).arg(actualSize) );
		return ReportResult_Finished;
	}
	return ReportResult_Finished;
}

} //namespace
